==> ae_lisz_app_data-0.0.5.tar.gz: ae_lisz_app_data-0.0.5/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# lisz_app_data portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_lisz_app_data/master?logo=python)](
    https://gitlab.com/ae-group/ae_lisz_app_data)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_lisz_app_data/coverage.svg)](
    https://ae-group.gitlab.io/ae_lisz_app_data/coverage/ae_lisz_app_data_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_lisz_app_data/mypy.svg)](
    https://ae-group.gitlab.io/ae_lisz_app_data/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_lisz_app_data/pylint.svg)](
    https://ae-group.gitlab.io/ae_lisz_app_data/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_lisz_app_data)](
    https://libraries.io/pypi/ae-lisz-app-data)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/#files)


## installation


Execute the following command for to use the ae.lisz_app_data module in your
application. It will install ae.lisz_app_data into your python (virtual) environment:
 
```shell script
pip install ae-lisz-app-data
```

If you instead want to contribute to this portion then first fork
[the ae_lisz_app_data repository at GitLab](https://gitlab.com/ae-group/ae_lisz_app_data "ae.lisz_app_data code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_lisz_app_data):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.lisz_app_data.html#module-ae.lisz_app_data
"ae_lisz_app_data documentation").

<!-- Common files version 0.0.47 deployed  version 0.0.0 (with 0.0.47)
     to https://gitlab.com/ae-group as ae_lisz_app_data module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project as ae-lisz-app-data package.
-->

==> ae_lisz_app_data-0.1.22.tar.gz: ae_lisz_app_data-0.1.22/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# lisz_app_data portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_lisz_app_data/master?logo=python)](
    https://gitlab.com/ae-group/ae_lisz_app_data)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_lisz_app_data/coverage.svg)](
    https://ae-group.gitlab.io/ae_lisz_app_data/coverage/ae_lisz_app_data_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_lisz_app_data/mypy.svg)](
    https://ae-group.gitlab.io/ae_lisz_app_data/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_lisz_app_data/pylint.svg)](
    https://ae-group.gitlab.io/ae_lisz_app_data/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_lisz_app_data)](
    https://libraries.io/pypi/ae-lisz-app-data)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_lisz_app_data)](
    https://pypi.org/project/ae-lisz-app-data/#files)


## installation


Execute the following command for to use the ae.lisz_app_data module in your
application. It will install ae.lisz_app_data into your python (virtual) environment:
 
```shell script
pip install ae-lisz-app-data
```

If you instead want to contribute to this portion then first fork
[the ae_lisz_app_data repository at GitLab](https://gitlab.com/ae-group/ae_lisz_app_data "ae.lisz_app_data code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_lisz_app_data):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.lisz_app_data.html#module-ae.lisz_app_data
"ae_lisz_app_data documentation").

<!-- Common files version 0.0.60 deployed version 0.1.16 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_lisz_app_data module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-lisz-app-data as namespace portion ae-lisz-app-data.
-->
